<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>MainWidget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="115"/>
        <source>No text recognized</source>
        <translation>未識別到文字</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="166"/>
        <source>Recognize language</source>
        <translation>識別語言</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>Simplified Chinese</source>
        <translation>簡體中文</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>English</source>
        <translation>英文</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>Traditional Chinese</source>
        <translation>繁體中文</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="204"/>
        <source>Copy text</source>
        <translation>複製文字</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="210"/>
        <source>Save as TXT</source>
        <translation>儲存為TXT</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="236"/>
        <source>Undo (Ctrl+Z)</source>
        <translation>復原 (Ctrl+Z)</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="247"/>
        <source>Redo (Ctrl+Shift+Z)</source>
        <translation>重做 (Ctrl+Shift+Z)</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="294"/>
        <location filename="../src/mainwidget.cpp" line="335"/>
        <source>Recognizing</source>
        <translation>正在識別</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="563"/>
        <source>Copied</source>
        <translation>已複製</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="75"/>
        <source>OCR Tool</source>
        <translation>圖文識別工具</translation>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <location filename="../src/resulttextview.cpp" line="22"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="24"/>
        <source>Cut</source>
        <translation>剪下</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="27"/>
        <source>Select All</source>
        <translation>全選</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="29"/>
        <source>Paste</source>
        <translation>貼上</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="283"/>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation>溫馨提示：圖像越簡潔清晰，識別越準確</translation>
    </message>
</context>
</TS>